==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/VirtualNetworksPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * HybridAKSNetworkSpec defines the desired state of HybridAKSNetwork
 * @property dnsServers Address of the DNS servers associated with the network
 * @property gateway Address of the Gateway associated with the network
 * @property infraVnetProfile
 * @property ipAddressPrefix IP Address Prefix of the network
 * @property vipPool Virtual IP Pool for Kubernetes
 * @property vmipPool IP Pool for Virtual Machines
 */
public data class VirtualNetworksPropertiesArgs(
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<String>? = null,
    public val infraVnetProfile: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>? = null,
    public val ipAddressPrefix: Output<String>? = null,
    public val vipPool: Output<List<VirtualNetworksPropertiesVipPoolArgs>>? = null,
    public val vmipPool: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0 }))
            .infraVnetProfile(infraVnetProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipAddressPrefix(ipAddressPrefix?.applyValue({ args0 -> args0 }))
            .vipPool(
                vipPool?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .vmipPool(
                vmipPool?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualNetworksPropertiesArgs].
 */
@PulumiTagMarker
public class VirtualNetworksPropertiesArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<String>? = null

    private var infraVnetProfile: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>? = null

    private var ipAddressPrefix: Output<String>? = null

    private var vipPool: Output<List<VirtualNetworksPropertiesVipPoolArgs>>? = null

    private var vmipPool: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>? = null

    /**
     * @param value Address of the DNS servers associated with the network
     */
    @JvmName("tnctualdqefddyud")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("hubidpxkbujkwbrk")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values Address of the DNS servers associated with the network
     */
    @JvmName("griokwimlvoehisx")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Address of the Gateway associated with the network
     */
    @JvmName("arceefhnutnyctkb")
    public suspend fun gateway(`value`: Output<String>) {
        this.gateway = value
    }

    /**
     * @param value
     */
    @JvmName("ortnajadjddokfof")
    public suspend
    fun infraVnetProfile(`value`: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>) {
        this.infraVnetProfile = value
    }

    /**
     * @param value IP Address Prefix of the network
     */
    @JvmName("dcxdptwwhramulwo")
    public suspend fun ipAddressPrefix(`value`: Output<String>) {
        this.ipAddressPrefix = value
    }

    /**
     * @param value Virtual IP Pool for Kubernetes
     */
    @JvmName("cvjsicmeafuivior")
    public suspend fun vipPool(`value`: Output<List<VirtualNetworksPropertiesVipPoolArgs>>) {
        this.vipPool = value
    }

    @JvmName("bkumbfuwmlripjxt")
    public suspend fun vipPool(vararg values: Output<VirtualNetworksPropertiesVipPoolArgs>) {
        this.vipPool = Output.all(values.asList())
    }

    /**
     * @param values Virtual IP Pool for Kubernetes
     */
    @JvmName("biolmsgvkeqloclm")
    public suspend fun vipPool(values: List<Output<VirtualNetworksPropertiesVipPoolArgs>>) {
        this.vipPool = Output.all(values)
    }

    /**
     * @param value IP Pool for Virtual Machines
     */
    @JvmName("cqvxwlaerkeybavs")
    public suspend fun vmipPool(`value`: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>) {
        this.vmipPool = value
    }

    @JvmName("qhsvecgkowksbhhd")
    public suspend fun vmipPool(vararg values: Output<VirtualNetworksPropertiesVmipPoolArgs>) {
        this.vmipPool = Output.all(values.asList())
    }

    /**
     * @param values IP Pool for Virtual Machines
     */
    @JvmName("mxogxdtcdbxparjm")
    public suspend fun vmipPool(values: List<Output<VirtualNetworksPropertiesVmipPoolArgs>>) {
        this.vmipPool = Output.all(values)
    }

    /**
     * @param value Address of the DNS servers associated with the network
     */
    @JvmName("tvicoarbexvmkiek")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values Address of the DNS servers associated with the network
     */
    @JvmName("ufbeanfmlhoqlquc")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Address of the Gateway associated with the network
     */
    @JvmName("lqcgkvetthkiyeba")
    public suspend fun gateway(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value
     */
    @JvmName("jybqlaqevakyxskh")
    public suspend fun infraVnetProfile(`value`: VirtualNetworksPropertiesInfraVnetProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.infraVnetProfile = mapped
    }

    /**
     * @param argument
     */
    @JvmName("icagkmgnqdijbblg")
    public suspend
    fun infraVnetProfile(argument: suspend VirtualNetworksPropertiesInfraVnetProfileArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualNetworksPropertiesInfraVnetProfileArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.infraVnetProfile = mapped
    }

    /**
     * @param value IP Address Prefix of the network
     */
    @JvmName("thvxcgxetejxbjef")
    public suspend fun ipAddressPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddressPrefix = mapped
    }

    /**
     * @param value Virtual IP Pool for Kubernetes
     */
    @JvmName("daxmsvdjdwjatvep")
    public suspend fun vipPool(`value`: List<VirtualNetworksPropertiesVipPoolArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("icxcakdfhmpewmxi")
    public suspend
    fun vipPool(argument: List<suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("nsobrjxjitaprseu")
    public suspend fun vipPool(
        vararg
        argument: suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("gwulovfovwakbguw")
    public suspend
    fun vipPool(argument: suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param values Virtual IP Pool for Kubernetes
     */
    @JvmName("edewkreylwpeuojg")
    public suspend fun vipPool(vararg values: VirtualNetworksPropertiesVipPoolArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vipPool = mapped
    }

    /**
     * @param value IP Pool for Virtual Machines
     */
    @JvmName("ljxfkoachwaravns")
    public suspend fun vmipPool(`value`: List<VirtualNetworksPropertiesVmipPoolArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("yladpqqnvukbjilq")
    public suspend
    fun vmipPool(argument: List<suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("vaxajlkvhuqbksks")
    public suspend fun vmipPool(
        vararg
        argument: suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("jxbklpvexgcgwtjf")
    public suspend
    fun vmipPool(argument: suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param values IP Pool for Virtual Machines
     */
    @JvmName("xfbvbwrxntjarmnu")
    public suspend fun vmipPool(vararg values: VirtualNetworksPropertiesVmipPoolArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmipPool = mapped
    }

    internal fun build(): VirtualNetworksPropertiesArgs = VirtualNetworksPropertiesArgs(
        dnsServers = dnsServers,
        gateway = gateway,
        infraVnetProfile = infraVnetProfile,
        ipAddressPrefix = ipAddressPrefix,
        vipPool = vipPool,
        vmipPool = vmipPool,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/hybridcontainerservice/kotlin/inputs/VirtualNetworksPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.hybridcontainerservice.kotlin.inputs

import com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * HybridAKSNetworkSpec defines the desired state of HybridAKSNetwork
 * @property dnsServers Address of the DNS servers associated with the network
 * @property gateway Address of the Gateway associated with the network
 * @property infraVnetProfile
 * @property ipAddressPrefix IP Address Prefix of the network
 * @property vipPool Virtual IP Pool for Kubernetes
 * @property vmipPool IP Pool for Virtual Machines
 */
public data class VirtualNetworksPropertiesArgs(
    public val dnsServers: Output<List<String>>? = null,
    public val gateway: Output<String>? = null,
    public val infraVnetProfile: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>? = null,
    public val ipAddressPrefix: Output<String>? = null,
    public val vipPool: Output<List<VirtualNetworksPropertiesVipPoolArgs>>? = null,
    public val vmipPool: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>? = null,
) :
    ConvertibleToJava<com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs> {
    override fun toJava():
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs =
        com.pulumi.azurenative.hybridcontainerservice.inputs.VirtualNetworksPropertiesArgs.builder()
            .dnsServers(dnsServers?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .gateway(gateway?.applyValue({ args0 -> args0 }))
            .infraVnetProfile(infraVnetProfile?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .ipAddressPrefix(ipAddressPrefix?.applyValue({ args0 -> args0 }))
            .vipPool(
                vipPool?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .vmipPool(
                vmipPool?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            ).build()
}

/**
 * Builder for [VirtualNetworksPropertiesArgs].
 */
@PulumiTagMarker
public class VirtualNetworksPropertiesArgsBuilder internal constructor() {
    private var dnsServers: Output<List<String>>? = null

    private var gateway: Output<String>? = null

    private var infraVnetProfile: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>? = null

    private var ipAddressPrefix: Output<String>? = null

    private var vipPool: Output<List<VirtualNetworksPropertiesVipPoolArgs>>? = null

    private var vmipPool: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>? = null

    /**
     * @param value Address of the DNS servers associated with the network
     */
    @JvmName("pnoyvcsmsfombtfl")
    public suspend fun dnsServers(`value`: Output<List<String>>) {
        this.dnsServers = value
    }

    @JvmName("hrviruxspfsqhgut")
    public suspend fun dnsServers(vararg values: Output<String>) {
        this.dnsServers = Output.all(values.asList())
    }

    /**
     * @param values Address of the DNS servers associated with the network
     */
    @JvmName("tcligtrbkvpgjmef")
    public suspend fun dnsServers(values: List<Output<String>>) {
        this.dnsServers = Output.all(values)
    }

    /**
     * @param value Address of the Gateway associated with the network
     */
    @JvmName("jfavtdxklosfimun")
    public suspend fun gateway(`value`: Output<String>) {
        this.gateway = value
    }

    /**
     * @param value
     */
    @JvmName("taujjjvjluqauojo")
    public suspend
    fun infraVnetProfile(`value`: Output<VirtualNetworksPropertiesInfraVnetProfileArgs>) {
        this.infraVnetProfile = value
    }

    /**
     * @param value IP Address Prefix of the network
     */
    @JvmName("fkvmumiesevsgpho")
    public suspend fun ipAddressPrefix(`value`: Output<String>) {
        this.ipAddressPrefix = value
    }

    /**
     * @param value Virtual IP Pool for Kubernetes
     */
    @JvmName("kgojglpvpbinyklh")
    public suspend fun vipPool(`value`: Output<List<VirtualNetworksPropertiesVipPoolArgs>>) {
        this.vipPool = value
    }

    @JvmName("fpvaxkjpmxxoldyj")
    public suspend fun vipPool(vararg values: Output<VirtualNetworksPropertiesVipPoolArgs>) {
        this.vipPool = Output.all(values.asList())
    }

    /**
     * @param values Virtual IP Pool for Kubernetes
     */
    @JvmName("inuscferhchwuqnt")
    public suspend fun vipPool(values: List<Output<VirtualNetworksPropertiesVipPoolArgs>>) {
        this.vipPool = Output.all(values)
    }

    /**
     * @param value IP Pool for Virtual Machines
     */
    @JvmName("rwqstdjykpmgfrfq")
    public suspend fun vmipPool(`value`: Output<List<VirtualNetworksPropertiesVmipPoolArgs>>) {
        this.vmipPool = value
    }

    @JvmName("uogchlieiynkpdfl")
    public suspend fun vmipPool(vararg values: Output<VirtualNetworksPropertiesVmipPoolArgs>) {
        this.vmipPool = Output.all(values.asList())
    }

    /**
     * @param values IP Pool for Virtual Machines
     */
    @JvmName("wgdgwrtjhkyuwlie")
    public suspend fun vmipPool(values: List<Output<VirtualNetworksPropertiesVmipPoolArgs>>) {
        this.vmipPool = Output.all(values)
    }

    /**
     * @param value Address of the DNS servers associated with the network
     */
    @JvmName("ydkyfwdupboijlyr")
    public suspend fun dnsServers(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param values Address of the DNS servers associated with the network
     */
    @JvmName("jtfgnilgkjgnoyau")
    public suspend fun dnsServers(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.dnsServers = mapped
    }

    /**
     * @param value Address of the Gateway associated with the network
     */
    @JvmName("qidnkdetxxxglcrw")
    public suspend fun gateway(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.gateway = mapped
    }

    /**
     * @param value
     */
    @JvmName("gcmdmvkkentllhfs")
    public suspend fun infraVnetProfile(`value`: VirtualNetworksPropertiesInfraVnetProfileArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.infraVnetProfile = mapped
    }

    /**
     * @param argument
     */
    @JvmName("ekruchidrxmegamg")
    public suspend
    fun infraVnetProfile(argument: suspend VirtualNetworksPropertiesInfraVnetProfileArgsBuilder.() -> Unit) {
        val toBeMapped = VirtualNetworksPropertiesInfraVnetProfileArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.infraVnetProfile = mapped
    }

    /**
     * @param value IP Address Prefix of the network
     */
    @JvmName("yfcyhhqicbrfalqb")
    public suspend fun ipAddressPrefix(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.ipAddressPrefix = mapped
    }

    /**
     * @param value Virtual IP Pool for Kubernetes
     */
    @JvmName("jaojpdwgkbadstxl")
    public suspend fun vipPool(`value`: List<VirtualNetworksPropertiesVipPoolArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("auhwjsekbaawvono")
    public suspend
    fun vipPool(argument: List<suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("idrivmxvjorifpgw")
    public suspend fun vipPool(
        vararg
        argument: suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param argument Virtual IP Pool for Kubernetes
     */
    @JvmName("jhenqoggecdiwuck")
    public suspend
    fun vipPool(argument: suspend VirtualNetworksPropertiesVipPoolArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworksPropertiesVipPoolArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.vipPool = mapped
    }

    /**
     * @param values Virtual IP Pool for Kubernetes
     */
    @JvmName("yqnsyeiejdulsojb")
    public suspend fun vipPool(vararg values: VirtualNetworksPropertiesVipPoolArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vipPool = mapped
    }

    /**
     * @param value IP Pool for Virtual Machines
     */
    @JvmName("qsurkidwusblawnp")
    public suspend fun vmipPool(`value`: List<VirtualNetworksPropertiesVmipPoolArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("lenusbuyhcxljlxj")
    public suspend
    fun vmipPool(argument: List<suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("aqcbvfufvdujvygg")
    public suspend fun vmipPool(
        vararg
        argument: suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param argument IP Pool for Virtual Machines
     */
    @JvmName("nwnrmnjlcsnjluvf")
    public suspend
    fun vmipPool(argument: suspend VirtualNetworksPropertiesVmipPoolArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            VirtualNetworksPropertiesVmipPoolArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.vmipPool = mapped
    }

    /**
     * @param values IP Pool for Virtual Machines
     */
    @JvmName("xfpodsbvlbtjoewy")
    public suspend fun vmipPool(vararg values: VirtualNetworksPropertiesVmipPoolArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.vmipPool = mapped
    }

    internal fun build(): VirtualNetworksPropertiesArgs = VirtualNetworksPropertiesArgs(
        dnsServers = dnsServers,
        gateway = gateway,
        infraVnetProfile = infraVnetProfile,
        ipAddressPrefix = ipAddressPrefix,
        vipPool = vipPool,
        vmipPool = vmipPool,
    )
}
